@@ -11,15 +11,12 @@ Usage::
 """
 import sys
 from datetime import datetime
-from typing import Dict, List
+from typing import Any, Dict, List
 
 if sys.version_info >= (3, 8):
     from typing import Literal
 else:
     from typing_extensions import Literal
-
-import sys
-
 if sys.version_info >= (3, 8):
     from typing import TypedDict
 else:
@@ -48,6 +45,7 @@ __all__ = (
     "OnFailureTypeDef",
     "OnSuccessTypeDef",
     "ProvisionedConcurrencyConfigListItemTypeDef",
+    "ResponseMetadata",
     "TracingConfigResponseTypeDef",
     "VpcConfigResponseTypeDef",
     "AddLayerVersionPermissionResponseTypeDef",
@@ -257,7 +255,7 @@ LayerTypeDef = TypedDict("LayerTypeDef", {"Arn": str, "CodeSize": int}, total=Fa
 
 LayerVersionContentOutputTypeDef = TypedDict(
     "LayerVersionContentOutputTypeDef",
-    {"Location": str, "CodeSha256": str, "CodeSize": int},
+    {"Location": str, "CodeSha256": str, "CodeSize": int, "ResponseMetadata": "ResponseMetadata"},
     total=False,
 )
 
@@ -324,6 +322,17 @@ ProvisionedConcurrencyConfigListItemTypeDef = TypedDict(
     total=False,
 )
 
+ResponseMetadata = TypedDict(
+    "ResponseMetadata",
+    {
+        "RequestId": str,
+        "HostId": str,
+        "HTTPStatusCode": int,
+        "HTTPHeaders": Dict[str, Any],
+        "RetryAttempts": int,
+    },
+)
+
 TracingConfigResponseTypeDef = TypedDict(
     "TracingConfigResponseTypeDef", {"Mode": Literal["Active", "PassThrough"]}, total=False
 )
